IsoVision
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 | isovision(
data,
whichIsoforms = NULL,
main = NULL,
main.cex = 2,
use.barplot = T,
barplot.width = 0.1,
barplot.fill = "white",
barplot.border = "black",
line.color = "black",
intron.reduction = 0.9,
n.chunks = 1000,
orf.lwd = 1.5,
orf.lty = 1,
norf.lwd = 1,
norf.lty = 4,
mar = 0.1,
terminal.style = "triangle",
terminal.fill = "white",
terminal.border = "black",
default.fill = "white",
default.border = "black",
legend.values = setNames(colnames(data)[-(1:8)], colnames(data)[-(1:8)]),
legend.colors = "Set3",
filename = "Rplots.pdf",
width = 11,
height = 8.5
)
|
data |
Data generated by |
whichIsoforms |
A character vector of isoform names or an integer vector for isoform ranks to visualize. If null, plots all isoforms. |
main |
The title. |
main.cex |
The |
use.barplot |
Whether or not to plot a barplot of total reads next to the track. |
barplot.width |
The relative width of the barplot (0.0 to 1.0). |
barplot.fill |
A vector of colors for the bars. Passed to the R barplot function. |
barplot.border |
A vector of colors for the border of the bars. Passed to the R barplot function. |
line.color |
The color of the track lines as a vector of the same length of the number of isoforms, an RColorBrewer palette or a single value. |
intron.reduction |
The reduction factor for intron widths to ensure long introns are shrunk for plotting. |
n.chunks |
The number of chunks to split the line into for intron scaling. Higher numbers mean more intron reduction. |
orf.lwd |
The border weight for exons in the ORF. |
orf.lty |
The border line type for exons in the ORF. |
norf.lwd |
The border weight for exons not in the ORF. |
norf.lty |
The border line type for exons not in the ORF. |
mar |
The margin. |
terminal.style |
The drawing style for the terminal exons. Options include "arrow" and "triangle". Any other value will draw a normal rectangular exon. |
terminal.fill |
The fill color of the terminal exons. |
terminal.border |
The border color of the terminal exons. |
default.fill |
The fill color of exons without any annotations. |
default.border |
The border color of exons without any annotations. |
legend.values |
A named character with names set to domain annotation names present in |
legend.colors |
Colors to be applied to domain annotations. Will be applied sequentially in the order that domains are defined in |
filename |
The name to save this plot as. |
width |
The width, in inches. |
height |
The height, in inches. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.